// Fill out your copyright notice in the Description page of Project Settings.


#include "BountyHunterCharacter.h"
#include "Kismet/GameplayStatics.h"

void ABountyHunterCharacter::SpawnMainBounty()
{
	UEVGameInstance* GI = Cast<UEVGameInstance>(GetGameInstance());
	if (!IsValid(GI->MainSaveGameInstanceRef)) return;
	CurrentMainBountyIndex = GI->MainSaveGameInstanceRef->LastMainBountyIndexInOpenWorld;

	UE_LOG(LogTemp, Warning, TEXT("Loaded current bounty as %d"), CurrentMainBountyIndex);

	if (GI->MainSaveGameInstanceRef->CurrentMainBountyIndexSave > CurrentMainBountyIndex) CompleteCurrentMainBounty(GI);
		
	if (MainBountyClasses.IsEmpty() || MainBountyClasses.Num() <= CurrentMainBountyIndex|| !IsValid(MainBountyClasses[CurrentMainBountyIndex]))
	{
		AllBountiesCompleted();
		if (CurrentMainBountyIndex >= 2 && !(UGameplayStatics::GetCurrentLevelName(GetWorld()) == "EnemyAITest"))
		{
			UGameplayStatics::OpenLevel(GetWorld(), FName("EnemyAITest"));
		}
		return;
	}

	CurrentMainBounty = GetWorld()->SpawnActor<AMainBountyClass>(MainBountyClasses[CurrentMainBountyIndex]);
	const FAttachmentTransformRules AttachmentTransformRules(EAttachmentRule::SnapToTarget, true);
	CurrentMainBounty->AttachToComponent(GetRootComponent(), AttachmentTransformRules);

	UGameplayStatics::GetCurrentLevelName(GetWorld()) == OpenWorldLevelName ? CurrentMainBounty->SpawnOpenWorldCheckpoint() : CurrentMainBounty->SpawnCheckpoints();
}

void ABountyHunterCharacter::CompleteCurrentMainBounty(UEVGameInstance* GI)
{
	// Collect rewards for bounty and move onto next
	UE_LOG(LogTemp, Warning, TEXT("Would be collecting reward for completing bounty %d"), CurrentMainBountyIndex);
	
	CurrentMainBountyIndex = GI->MainSaveGameInstanceRef->CurrentMainBountyIndexSave;
	GI->MainSaveGameInstanceRef->LastMainBountyIndexInOpenWorld = CurrentMainBountyIndex;
	UGameplayStatics::SaveGameToSlot(GI->MainSaveGameInstanceRef, "MainSave", 0);
}

void ABountyHunterCharacter::AllBountiesCompleted()
{
	UE_LOG(LogTemp, Warning, TEXT("Game Completed!!!! No more Bounties left... or you forgot to set a bounty at one of the indexes oof"));
}

void ABountyHunterCharacter::BeginPlay()
{
	if (UGameplayStatics::DoesSaveGameExist("MainSave", 0)) SpawnMainBounty();
	Super::BeginPlay();
}

void ABountyHunterCharacter::Tick(float DeltaTime)
{
	Super::Tick(DeltaTime);
}

